@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_common.class.php,v 1.13 2003/08/24 13:10:26 lukasz Exp $
+ *  $Id: LMSDB_common.class.php,v 1.19 2003/10/08 04:39:38 lukasz Exp $
  */
 
 /*
@@ -30,8 +30,8 @@
 
 Class LMSDB_common
 {
-	var $_version="1.1.2b";
-	var $_revision='$Revision: 1.13 $';
+	var $_version="1.1.5 Amaonet";
+	var $_revision='$Revision: 1.19 $';
 	
 	// Driver powinien nadpisa t zmienn wartoci TRUE, eby
 	// funkcja inicjujca baze danych wiedziaa e driver si poprawnie
@@ -63,15 +63,21 @@ Class LMSDB_common
 
 		// Inicjuje poczenie do bazy danych
 	
-		$this->_driver_connect($dbhost,$dbuser,$dbpasswd,$dbname);
+		return $this->_driver_connect($dbhost,$dbuser,$dbpasswd,$dbname);
+	}
+
+	function Destroy()
+	{
+		return $this->_driver_disconnect();
 	}
 
 	function Execute($query, $inputarray = NULL)
 	{
-
 		// wykonuje query sql'owe, jednoczenie je parsujc
-	
-		return $this->_driver_execute($this->_query_parser($query,$inputarray));
+ // 		echo $this->_query_parser($query,$inputarray)."<BR>";
+		$this->_driver_execute($this->_query_parser($query,$inputarray));
+		// i zwraca ilo zmodyfikowanych wierszy
+		return $this->_driver_affected_rows();
 	}
 
 	function GetAll($query = NULL, $inputarray = NULL)
@@ -82,6 +88,8 @@ Class LMSDB_common
 		if($query)
 			$this->Execute($query, $inputarray);
 
+		unset($result);
+
 		while($row = $this->_driver_fetchrow_assoc())
 			$result[] = $row;
 		
@@ -93,6 +101,8 @@ Class LMSDB_common
 		if($query)
 			$this->Execute($query, $inputarray);
 
+		unset($result);
+
 		while($row = $this->_driver_fetchrow_assoc())
 			$result[$row[$key]] = $row;
 
@@ -112,6 +122,8 @@ Class LMSDB_common
 		if($query)
 			$this->Execute($query, $inputarray);
 
+		unset($result);
+
 		while($row = $this->_driver_fetchrow_num())
 			$result[] = $row[0];
 		
@@ -123,6 +135,8 @@ Class LMSDB_common
 		if($query)
 			$this->Execute($query, $inputarray);
 
+		unset($result);
+
 		list($result) = $this->_driver_fetchrow_num();
 
 		return $result;
@@ -143,6 +157,16 @@ Class LMSDB_common
 		return $this->_driver_listtables();
 	}
 
+	function BeginTrans()
+	{
+		return $this->_driver_begintrans();
+	}
+
+	function CommitTrans()
+	{
+		return $this->_driver_committrans();
+	}
+
 	function _query_parser($query, $inputarray = NULL)
 	{
 		// najpierw sparsujmy wszystkie specjalne meta mieci.
@@ -195,6 +219,24 @@ Class LMSDB_common
 
 /* 
  * $Log: LMSDB_common.class.php,v $
+ * Revision 1.19  2003/10/08 04:39:38  lukasz
+ * - temporary save
+ *
+ * Revision 1.18  2003/10/06 05:33:04  lukasz
+ * - temporary save / lot of fixes
+ *
+ * Revision 1.17  2003/09/12 22:22:52  alec
+ * Execute zwraca ilo zmodyfikowanych wierszy dla zapyta UPDATE, DELETE, INSERT
+ *
+ * Revision 1.16  2003/09/10 00:16:19  lukasz
+ * - LMSDB::Destroy();
+ *
+ * Revision 1.15  2003/08/28 21:07:21  lukasz
+ * - added support for transactions
+ *
+ * Revision 1.14  2003/08/27 19:25:18  lukasz
+ * - unset result before returning it
+ *
  * Revision 1.13  2003/08/24 13:10:26  lukasz
  * - added few comments
  * - s/<?/<?php/g
