@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_driver_mysql.class.php,v 1.12 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: LMSDB_driver_mysql.class.php,v 1.17 2003/09/12 22:34:21 alec Exp $
  */
 
 /*
@@ -35,13 +35,13 @@ class LMSDB_driver_mysql extends LMSDB_common
 
 	function LMSDB_driver_mysql($dbhost,$dbuser,$dbpasswd,$dbname)
 	{
-		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.12 $').')';
+		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.17 $').')';
 		$this->Connect($dbhost,$dbuser,$dbpasswd,$dbname);
 	}
 
 	function _driver_connect($dbhost,$dbuser,$dbpasswd,$dbname)
 	{
-		if($this->_dblink = mysql_connect($dbaddr,$dbuser,$dbpasswd))
+		if($this->_dblink = mysql_connect($dbhost,$dbuser,$dbpasswd))
 		{
 			$this->_dbhost = $dbhost;
 			$this->_dbuser = $dbuser;
@@ -49,6 +49,11 @@ class LMSDB_driver_mysql extends LMSDB_common
 		}
 		return $this->_dblink;
 	}
+
+	function _driver_disconnect()
+	{
+		return mysql_close($this->_dblink);
+	}
 	
 	function _driver_selectdb($dbname)
 	{
@@ -85,6 +90,14 @@ class LMSDB_driver_mysql extends LMSDB_common
 			return FALSE;
 	}
 
+	function _driver_affected_rows()
+	{
+		if(! $this->_error)
+			return mysql_affected_rows();
+		else
+			return FALSE;
+	}
+	
 	function _driver_now()
 	{
 		return 'UNIX_TIMESTAMP()';
@@ -106,11 +119,37 @@ class LMSDB_driver_mysql extends LMSDB_common
 		$this->_result = mysql_list_tables($this->_dbname,$this->_dblink);
 		return $this->GetCol();
 	}
-		
+
+	function _driver_begintrans()
+	{
+		// mysql nie obsuguje transakcji
+		return TRUE;
+	}
+
+	function _driver_committrans()
+	{
+		return TRUE;
+	}
 }
 
 /* 
  * $Log: LMSDB_driver_mysql.class.php,v $
+ * Revision 1.17  2003/09/12 22:34:21  alec
+ * bug fix (I think so)
+ *
+ * Revision 1.16  2003/09/12 22:22:52  alec
+ * Execute zwraca ilo zmodyfikowanych wierszy dla zapyta UPDATE, DELETE, INSERT
+ *
+ * Revision 1.15  2003/09/10 00:16:19  lukasz
+ * - LMSDB::Destroy();
+ *
+ * Revision 1.14  2003/08/31 03:34:20  lukasz
+ * - maa literwka powodujca to i driver od MySQL'a nie dostawa informacji
+ *   o hocie z lms.ini, a co za tym idzie zawsze czy si z localhostem.
+ *
+ * Revision 1.13  2003/08/28 21:07:26  lukasz
+ * - added support for transactions
+ *
  * Revision 1.12  2003/08/24 13:12:54  lukasz
  * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
  *   redhat's :>
