@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_driver_postgres.class.php,v 1.6 2003/08/24 14:06:35 lukasz Exp $
+ *  $Id: LMSDB_driver_postgres.class.php,v 1.12 2003/10/11 03:45:20 lukasz Exp $
  */
 
 /*
@@ -35,13 +35,20 @@ class LMSDB_driver_postgres extends LMSDB_common
 
 	function LMSDB_driver_postgres($dbhost,$dbuser,$dbpasswd,$dbname)
 	{
-		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.6 $').')';
+		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.12 $').')';
 		$this->Connect($dbhost,$dbuser,$dbpasswd,$dbname);
 	}
 
 	function _driver_connect($dbhost,$dbuser,$dbpasswd,$dbname)
 	{
-		if($this->_dblink = pg_connect(($host != '' ? 'host='.$dbhost : '' ).' user='.$dbuser.' password='.$dbpasswd.' dbname='.$dbname))
+		$cstring = join(' ',array(
+			($dbhost != '' ? 'host='.$dbhost : ''),
+			($dbuser != '' ? 'user='.$dbuser : ''),
+			($dbpasswd != '' ? 'password='.$dbpasswd : ''),
+			($dbname != '' ? 'dbname='.$dbname : '')
+		));
+		
+		if($this->_dblink = pg_connect($cstring))
 		{
 			$this->_dbhost = $dbhost;
 			$this->_dbuser = $dbuser;
@@ -51,6 +58,11 @@ class LMSDB_driver_postgres extends LMSDB_common
 		else
 			return FALSE;
 	}
+
+	function _driver_disconnect()
+	{
+		return pg_close($this->_dblink);
+	}
 	
 	function _driver_execute($query)
 	{
@@ -80,6 +92,14 @@ class LMSDB_driver_postgres extends LMSDB_common
 		else
 			return FALSE;
 	}
+	
+	function _driver_affected_rows()
+	{
+		if(! $this->_error)
+			return pg_affected_rows($this->_result);
+		else
+			return FALSE;
+	}
 
 	function _driver_now()
 	{
@@ -99,13 +119,40 @@ class LMSDB_driver_postgres extends LMSDB_common
 
 	function _driver_listtables()
 	{
-		return $this->GetCol('SELECT relname AS name FROM pg_class WHERE relkind = \'r\' and relname !~ \'^pg_\'');
-	}		
-		
+		return $this->GetCol('SELECT relname AS name FROM pg_class WHERE relkind = \'r\' and relname !~ \'^pg_\' and relname !~ \'^sql_\'');
+	}
+
+	function _driver_begintrans()
+	{
+		return $this->Execute('BEGIN');
+	}
+
+	function _driver_committrans()
+	{
+		return $this->Execute('COMMIT');
+	}
 }
 
 /* 
  * $Log: LMSDB_driver_postgres.class.php,v $
+ * Revision 1.12  2003/10/11 03:45:20  lukasz
+ * - http://lists.rulez.pl/lms/1242.html
+ *
+ * Revision 1.11  2003/09/12 22:22:52  alec
+ * Execute zwraca ilo zmodyfikowanych wierszy dla zapyta UPDATE, DELETE, INSERT
+ *
+ * Revision 1.10  2003/09/10 20:17:17  alec
+ * fatal error in postgres disconnect()
+ *
+ * Revision 1.9  2003/09/10 00:16:19  lukasz
+ * - LMSDB::Destroy();
+ *
+ * Revision 1.8  2003/08/28 21:07:33  lukasz
+ * - added support for transactions
+ *
+ * Revision 1.7  2003/08/25 15:59:12  alec
+ * Poprawka na nowsze wersje postgresa
+ *
  * Revision 1.6  2003/08/24 14:06:35  lukasz
  * - fixed bug #0000061 - added missing param for pg_fetch_array (but it's
  *   propably only workarround)
