@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: Session.class.php,v 1.37 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: Session.class.php,v 1.41 2003/12/01 04:18:37 lukasz Exp $
  */
 
 class Session {
@@ -35,44 +35,49 @@ class Session {
 	var $last;
 	var $lastip;
 	var $error;
-	var $_version = NULL;
+	var $_version = '1.1.5 Amaonet';
+	var $_revision = '$Revision: 1.41 $';
 
-	function Session($ADB,$timeout = 600)
+	function Session(&$DB,$timeout = 600)
 	{
-		$this->_version = eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.37 $');
 		session_start();
-		$this->ADB = $ADB;
+		$this->DB = &$DB;
 		$loginform = $_POST[loginform];
-		if(isset($loginform)){
+		if(isset($loginform))
+		{
 			$this->login = $loginform[login];
 			$this->passwd = $loginform[pwd];
 			$_SESSION[session_timestamp] = time();
 			writesyslog("Login attempt by ".$this->login,LOG_INFO);
-		}elseif($this->ADB->GetOne('SELECT COUNT(id) FROM admins') == 0){
+		}
+		elseif($this->DB->GetOne('SELECT COUNT(id) FROM admins') == 0)
+		{
 			$this->islogged = TRUE;
 			$this->passwd = 'EMPTY';
 			$this->logname = 'nie zalogowany';
 			$_GET[m] = 'adminadd';
 			return TRUE;
-		}else{
+		}
+		else
+		{
 			$this->login = $_SESSION[session_login];
 			$this->passwd = $_SESSION[session_passwd];
 		}
 		
 		if($this->VerifyPassword()&&$this->TimeOut($timeout)){
 			$this->islogged = TRUE;
-			$admindata = $this->ADB->GetRow("SELECT id, name FROM admins WHERE login=?",array($this->login));
+			$admindata = $this->DB->GetRow("SELECT id, name FROM admins WHERE login=?",array($this->login));
 			$this->id = $admindata[id];
 			$this->logname = $admindata[name];
 			$this->last = $_SESSION[session_last];
 			$this->lastip = $_SESSION[session_lastip];
 			if(isset($loginform))
 			{
-				$admindata = $this->ADB->GetRow("SELECT lastlogindate, lastloginip FROM admins WHERE id=?",array($this->id));
+				$admindata = $this->DB->GetRow("SELECT lastlogindate, lastloginip FROM admins WHERE id=?",array($this->id));
 				$this->last = $admindata[lastlogindate];
 				$this->lastip = $admindata[lastloginip];
 				
-				$this->ADB->Execute("UPDATE admins SET lastlogindate=?, lastloginip=? WHERE id=?",array(time(),$_SERVER[REMOTE_ADDR],$this->id));
+				$this->DB->Execute("UPDATE admins SET lastlogindate=?, lastloginip=? WHERE id=?",array(time(),$_SERVER[REMOTE_ADDR],$this->id));
 				writesyslog("User ".$this->login." logged in",LOG_INFO);
 			}
 			$_SESSION[session_login] = $this->login;
@@ -84,12 +89,17 @@ class Session {
 			if(isset($loginform))
 			{
 				writesyslog("Bad password for ".$this->login,LOG_WARNING);
-				$this->ADB->Execute("UPDATE admins SET failedlogindate=?, failedloginip=? WHERE login=?",array(time(),$_SERVER[REMOTE_ADDR],$this->login));
+				$this->DB->Execute("UPDATE admins SET failedlogindate=?, failedloginip=? WHERE login=?",array(time(),$_SERVER[REMOTE_ADDR],$this->login));
 			}
 			$this->LogOut();
 		}
 	}
 
+	function _postinit()
+	{
+		return TRUE;
+	}
+
 	function LogOut()
 	{
 		if ($this->islogged)
@@ -116,8 +126,8 @@ class Session {
 	
 	function VerifyPassword()
 	{
-		$dbpasswd = $this->ADB->GetOne("SELECT passwd FROM admins WHERE login=?",array($this->login));
-		$dblogin = $this->ADB->GetOne("SELECT login FROM admins WHERE login=?",array($this->login));
+		$dbpasswd = $this->DB->GetOne("SELECT passwd FROM admins WHERE login=?",array($this->login));
+		$dblogin = $this->DB->GetOne("SELECT login FROM admins WHERE login=?",array($this->login));
 		if (crypt($this->passwd,$dbpasswd)==$dbpasswd)
 			return TRUE;
 		else 
@@ -133,6 +143,18 @@ class Session {
 
 /*
  * $Log: Session.class.php,v $
+ * Revision 1.41  2003/12/01 04:18:37  lukasz
+ * - tsave
+ *
+ * Revision 1.40  2003/12/01 04:10:46  lukasz
+ * - typo
+ *
+ * Revision 1.39  2003/12/01 04:09:31  lukasz
+ * - tsave
+ *
+ * Revision 1.38  2003/09/05 02:07:05  lukasz
+ * - massive attack: s/this->ADB->/this->DB->/g
+ *
  * Revision 1.37  2003/08/24 13:12:54  lukasz
  * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
  *   redhat's :>
