@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: adminadd.php,v 1.19 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: adminadd.php,v 1.20 2003/10/05 21:09:28 alec Exp $
  */
 
 $adminadd = $_POST[adminadd];
@@ -79,7 +79,7 @@ foreach($access[table] as $idx => $row)
 	$accesslist[] = $row;
 }
 
-$layout[pagetitle]="Dodaj nowego administratora";
+$layout[pagetitle]="Nowy administrator";
 $SMARTY->assign("layout",$layout);
 $SMARTY->assign("adminadd",$adminadd);
 $SMARTY->assign("error",$error);
@@ -88,6 +88,9 @@ $SMARTY->display("adminadd.html");
 
 /*
  * $Log: adminadd.php,v $
+ * Revision 1.20  2003/10/05 21:09:28  alec
+ * ujednolicenie interfejsu
+ *
  * Revision 1.19  2003/08/24 13:12:54  lukasz
  * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
  *   redhat's :>
