@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: adminedit.php,v 1.19 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: adminedit.php,v 1.22 2003/10/03 15:02:52 alec Exp $
  */
 
 if(!$LMS->AdminExists($_GET[id]))
@@ -44,10 +44,12 @@ if(isset($admininfo))
 		$error[login] = "Podany login jest ju zajty!";
 
 	if($admininfo[login] == "")
-		$error[login] = "To pole nie moe by puste!";
+		$error[login] = "Pole login nie moe by puste!";
+	elseif(!eregi("^[a-z0-9.-_]+$",$admininfo[login]))
+		$error[login] = "Login zawiera niepoprawne znaki!";
 
 	if($admininfo[name] == "")
-		$error[name] = "To pole nie moe by puste!";
+		$error[name] = "Pole 'imi i nazwisko' nie moe by puste!";
 
 	if($admininfo[email]!="" && !check_email($admininfo[email]))
 		$error[email] = "Podany email nie wydaje si by poprawny!";
@@ -79,7 +81,7 @@ foreach($LMS->GetAdminInfo($_GET[id]) as $key => $value)
 	if(!isset($admininfo[$key]))
 		$admininfo[$key] = $value;
 
-$layout[pagetitle]="Edycja danych administratora ".$LMS->GetAdminName($_GET[id]);
+$layout[pagetitle]="Edycja danych administratora: ".$LMS->GetAdminName($_GET[id]);
 
 $rights = $LMS->GetAdminRights($_GET[id]);
 
@@ -100,6 +102,15 @@ $SMARTY->assign("layout",$layout);
 $SMARTY->display("admininfo.html");
 /*
  * $Log: adminedit.php,v $
+ * Revision 1.22  2003/10/03 15:02:52  alec
+ * ujednolicenie interfejsu
+ *
+ * Revision 1.21  2003/09/15 10:48:45  lukasz
+ * - http://bts.rulez.pl/bug_view_page.php?bug_id=0000072
+ *
+ * Revision 1.20  2003/09/05 13:11:23  lukasz
+ * - nowy sposb wywietlania informacji o bdach
+ *
  * Revision 1.19  2003/08/24 13:12:54  lukasz
  * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
  *   redhat's :>
@@ -108,4 +119,4 @@ $SMARTY->display("admininfo.html");
  * - added CVS Log tags
  *
  */
-?>
\ No newline at end of file
+?>
