@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,14 +21,21 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: logout.php,v 1.15 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: logout.php,v 1.16 2003/11/25 16:56:02 alec Exp $
  */
 
-$SESSION->LogOut();
-header("Location: ?m=welcome");
+if($_GET[is_sure]=="1") 
+{
+	$SESSION->LogOut();
+	header("Location: ?m=welcome");
+} else
+	header("Location: ?m=".$_SESSION[lastmodule]);    
 
 /*
  * $Log: logout.php,v $
+ * Revision 1.16  2003/11/25 16:56:02  alec
+ * poprawiony BTS_0000082
+ *
  * Revision 1.15  2003/08/24 13:12:54  lukasz
  * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
  *   redhat's :>
