@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: mailingsend.php,v 1.18 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: mailingsend.php,v 1.19 2003/09/05 13:11:24 lukasz Exp $
  */
 
 $layout[pagetitle]="Mailing";
@@ -29,16 +29,16 @@ $layout[pagetitle]="Mailing";
 $mailing = $_POST[mailing];
 
 if($mailing[group] < 0 || $mailing[group] > 3)
-	$error[group] = TRUE;
+	$error[group] = "Wybrae bdn grup uytkownikw";
 
 if($mailing[sender]=="")
-	$error[sender] = TRUE;
+	$error[sender] = "Prosz poda e-mail nadawcy!";
 
 if($mailing[from]=="")
-	$error[from] = TRUE;
+	$error[from] = "Prosz poda nadawc!";
 
 if($mailing[subject]=="")
-	$error[subject] = TRUE;
+	$error[subject] = "Prosz poda temat listu!";
 
 if($error)
 {
@@ -61,6 +61,9 @@ if($error)
 }
 /*
  * $Log: mailingsend.php,v $
+ * Revision 1.19  2003/09/05 13:11:24  lukasz
+ * - nowy sposb wywietlania informacji o bdach
+ *
  * Revision 1.18  2003/08/24 13:12:54  lukasz
  * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
  *   redhat's :>
@@ -69,4 +72,4 @@ if($error)
  * - added CVS Log tags
  *
  */
-?>
\ No newline at end of file
+?>
