@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netadd.php,v 1.22 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: netadd.php,v 1.25 2003/10/05 21:30:25 alec Exp $
  */
 
 $netadd = $_POST[netadd];
@@ -51,13 +51,13 @@ if(isset($netadd))
 	if($netadd[name]=="")
 		$error[name] = "Musisz poda nazw sieci!";
 	elseif(!eregi("^[.a-z0-9-]+$",$netadd[name]))
-		$error[name] = "Podana nazwa zawiera niepoprawne znaki!";
+		$error[name] = "Podana nazwa sieci zawiera niepoprawne znaki!";
 	
 	if($netadd[domain] != "" && !eregi("^[.a-z0-9-]+$",$netadd[domain]))
-		$error[domain] = "Podana nazwa zawiera niepoprawne znaki!";
+		$error[domain] = "Podana nazwa domeny zawiera niepoprawne znaki!";
 	
 	if(!check_ip($netadd[address]))
-		$error[address] = "Podany adres IP jest nieprawidowy!";
+		$error[address] = "Podany adres IP sieci jest nieprawidowy!";
 	else
 	{
 		if(getnetaddr($netadd[address],prefix2mask($netadd[prefix]))!=$netadd[address])
@@ -68,36 +68,39 @@ if(isset($netadd))
 		else
 		{
 			if($LMS->NetworkOverlaps($netadd[address],prefix2mask($netadd[prefix])))
-				$error[address] = "Podana sie pokrywa si z inn sieci!";
+				$error[address] = "Podany adres sieci pokrywa si z inn sieci!";
 		}
 	}
-	
+
+	if($netadd[interface] != '' && !eregi('^[a-z0-9]+$',$netadd[interface]))
+		$error[interface] = "Niepoprawna nazwa interfejsu!";
+
 	if($netadd[dns]!="" && !check_ip($netadd[dns]))
-		$error[dns] = "Podany adres IP jest nieprawidowy!";
+		$error[dns] = "Podany adres IP serwera DNS jest nieprawidowy!";
 	
 	if($netadd[dns2]!="" && !check_ip($netadd[dns2]))
-		$error[dns2] = "Podany adres IP jest nieprawidowy!";
+		$error[dns2] = "Podany adres IP serwera DNS jest nieprawidowy!";
 	
 	if($netadd[wins]!="" && !check_ip($netadd[wins]))
-		$error[wins] = "Podany adres IP jest nieprawidowy!";
+		$error[wins] = "Podany adres IP serwera WINS jest nieprawidowy!";
 	
 	if($netadd[gateway]!="")
 		if(!check_ip($netadd[gateway]))
-			$error[gateway] = "Podany adres IP jest nieprawidowy!";
+			$error[gateway] = "Podany adres IP bramy jest nieprawidowy!";
 	elseif(!isipin($netadd[gateway],getnetaddr($netadd[address],prefix2mask($netadd[prefix])),prefix2mask($netadd[prefix])))
-		$error[gateway] = "Podany adres gateway'a nie pasuje do adresu sieci!";
+		$error[gateway] = "Podany adres bramy nie pasuje do adresu sieci!";
 	
 	if($netadd[dhcpstart]!="")
 		if(!check_ip($netadd[dhcpstart]))
-			$error[dhcpstart] = "Podany adres IP jest nieprawidowy!";
+			$error[dhcpstart] = "Podany adres IP pocztku zakresu DHCP jest nieprawidowy!";
 	elseif(!isipin($netadd[dhcpstart],getnetaddr($netadd[address],prefix2mask($netadd[prefix])),prefix2mask($netadd[prefix])) && $netadd[address]!="")
-		$error[dhcpstart] = "Podany adres IP nie naley do tej sieci!";
+		$error[dhcpstart] = "Podany adres IP pocztku zakresu DHCP nie naley do tej sieci!";
 	
 	if($netadd[dhcpend]!="")
 		if(!check_ip($netadd[dhcpend]))
-			$error[dhcpend] = "Podany adres IP jest nieprawidowy!";
+			$error[dhcpend] = "Podany adres IP koca zakresu DHCP jest nieprawidowy!";
 	elseif(!isipin($netadd[dhcpend],getnetaddr($netadd[address],prefix2mask($netadd[prefix])),prefix2mask($netadd[prefix])) && $netadd[address]!="")
-		$error[dhcpend] = "Podany adres IP nie naley do tej sieci!";
+		$error[dhcpend] = "Podany adres IP koca zakresu DHCP nie naley do tej sieci!";
 	
 	if(!$error[dhcpstart] && !$error[dhcpend])
 	{
@@ -115,7 +118,7 @@ if(isset($netadd))
 
 }
 
-$layout[pagetitle]="Dodaj sie";
+$layout[pagetitle]="Nowa sie";
 
 $prefixlist = $LMS->GetPrefixList();
 $netlist = $LMS->GetNetworkList();
@@ -128,6 +131,15 @@ $SMARTY->display("netadd.html");
 
 /*
  * $Log: netadd.php,v $
+ * Revision 1.25  2003/10/05 21:30:25  alec
+ * ujednolicenie naglowkow
+ *
+ * Revision 1.24  2003/09/05 13:11:24  lukasz
+ * - nowy sposb wywietlania informacji o bdach
+ *
+ * Revision 1.23  2003/08/30 01:11:21  lukasz
+ * - nowe pole w licie sieci: interfejs
+ *
  * Revision 1.22  2003/08/24 13:12:54  lukasz
  * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
  *   redhat's :>
@@ -136,4 +148,4 @@ $SMARTY->display("netadd.html");
  * - added CVS Log tags
  *
  */
-?>
\ No newline at end of file
+?>
