@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netedit.php,v 1.21 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: netedit.php,v 1.25 2003/10/03 15:59:46 alec Exp $
  */
 
 if(!$LMS->NetworkExists($_GET[id]))
@@ -31,8 +31,13 @@ if(!$LMS->NetworkExists($_GET[id]))
 }
 
 
+if (isset($_SESSION[ntlp][$_GET[id]]) && !isset($_GET[page]))
+	$_GET[page] = $_SESSION[ntlp][$_GET[id]];
+	
+$_SESSION[ntlp][$_GET[id]] = $_GET[page];
+
 $networkdata = $_POST[networkdata];
-$network = $LMS->GetNetworkRecord($_GET[id]);
+$network = $LMS->GetNetworkRecord($_GET[id],$_GET[page],1024);
 
 
 if(isset($networkdata))
@@ -44,7 +49,7 @@ if(isset($networkdata))
 	$networkdata[addresslong] = ip_long($networkdata[address]);
 	$networkdata[mask] = prefix2mask($networkdata[prefix]);
 	if(!check_ip($networkdata[address]))
-		$error[address] = "Podany adres IP jest nieprawidowy!";
+		$error[address] = "Podany adres IP sieci jest nieprawidowy!";
 	else
 	{
 		if(getnetaddr($networkdata[address],prefix2mask($networkdata[prefix]))!=$networkdata[address])
@@ -79,50 +84,53 @@ if(isset($networkdata))
 		}
 	}
 
+	if($networkdata[interface] != "" && !eregi('^[a-z0-9]+$',$networkdata[interface]))
+		$error[interface] = "Niepoprawna nazwa interfejsu!";
+
 	if($networkdata[name]=="")
 		$error[name] = "Musisz poda nazw sieci!";
 	elseif(!eregi("^[.a-z0-9-]+$",$networkdata[name]))
-		$error[name] = "Podana nazwa zawiera nieprawidowe znaki!";
+		$error[name] = "Podana nazwa sieci zawiera nieprawidowe znaki!";
 
 	if($networkdata[domain]!="" && !eregi("^[.a-z0-9-]+$",$networkdata[domain]))
 		$error[domain] = "Podana domena zawiera nieprawidow znaki";
 
 	if($networkdata[dns]!="" && !check_ip($networkdata[dns]))
-		$error[dns] = "Podany adres IP jest nie prawidowy!";
+		$error[dns] = "Podany adres IP serwera DNS jest nie prawidowy!";
 
 	if($networkdata[dns2]!="" && !check_ip($networkdata[dns2]))
-		$error[dns2] = "Podany adres IP jest nie prawidowy!";
+		$error[dns2] = "Podany adres IP serwera DNS jest nie prawidowy!";
 
 	if($networkdata[wins]!="" && !check_ip($networkdata[wins]))
 		$error[wins] = "Podany adres IP jest nie prawidowy!";
 
 	if($networkdata[gateway]!="")
 		if(!check_ip($networkdata[gateway]))
-			$error[gateway] = "Podany adres IP jest nie prawidowy!";
+			$error[gateway] = "Podany adres IP bramy jest nie prawidowy!";
 		else
 			if(!isipin($networkdata[gateway],getnetaddr($networkdata[address],prefix2mask($networkdata[prefix])),prefix2mask($networkdata[prefix])))
-				$error[gateway] = "Podany adres gateway'a nie pasuje do adresu sieci!";
+				$error[gateway] = "Podany adres bramy nie pasuje do adresu sieci!";
 
 	if($networkdata[dhcpstart]!="")
 		if(!check_ip($networkdata[dhcpstart]))
-			$error[dhcpstart] = "Podany adres IP jest nieprawidowy!";
+			$error[dhcpstart] = "Podany adres IP pocztka zakresu DHCP jest nieprawidowy!";
 		else
 			if(!isipin($networkdata[dhcpstart],getnetaddr($networkdata[address],prefix2mask($networkdata[prefix])),prefix2mask($networkdata[prefix])) && $networkdata[address]!="")
-				$error[dhcpstart] = "Podany adres IP nie naley do tej sieci!";
+				$error[dhcpstart] = "Podany adres IP pocztka zakresu DHCP nie naley do tej sieci!";
 
 	if($networkdata[dhcpend]!="")
 		if(!check_ip($networkdata[dhcpend]))
-			$error[dhcpend] = "Podany adres IP jest nieprawidowy!";
+			$error[dhcpend] = "Podany adres IP koca zakresu DHCP jest nieprawidowy!";
 		else
 			if(!isipin($networkdata[dhcpend],getnetaddr($networkdata[address],prefix2mask($networkdata[prefix])),prefix2mask($networkdata[prefix])) && $networkdata[address]!="")
-				$error[dhcpend] = "Podany adres IP nie naley do tej sieci!";
+				$error[dhcpend] = "Podany adres IP koca zakresu DHCP nie naley do tej sieci!";
 	
 	if(!$error[dhcpstart] && !$error[dhcpend])
 	{
 		if(($networkdata[dhcpstart]!="" && $networkdata[dhcpend]=="")||($networkdata[dhcpstart]=="" && $networkdata[dhcpend]!=""))
 			$error[dhcp] = "Musisz poda obydwa zakresy IP dla DHCP!";
 		if($networkdata[dhcpstart]!="" && $networkdata[dhcpend]!="" && !(ip_long($networkdata[dhcpend]) > ip_long($networkdata[dhcpstart])))
-			$error[dhcp] = "Koniec zakresu DHCP musi by wikszy ni start!";
+			$error[dhcp] = "Koniec zakresu DHCP musi by wikszy ni pocztek!";
 	}
 	
 	if(!$error)
@@ -135,7 +143,8 @@ if(isset($networkdata))
 		header("Location: ?m=netinfo&id=".$networkdata[id]);
 		die;
 	}	
-	
+
+	$network[interface] = $networkdata[interface];
 	$network[prefix] = $networkdata[prefix];
 	$network[address] = $networkdata[address];
 	$network[size] = $networkdata[size];
@@ -151,7 +160,7 @@ if(isset($networkdata))
 
 $prefixlist = $LMS->GetPrefixList();
 $networks = $LMS->GetNetworks();
-$layout[pagetitle]="Edytowanie sieci";
+$layout[pagetitle]="Edytowanie sieci: ".$network[name];
 $SMARTY->assign("unlockedit",TRUE);
 $SMARTY->assign("layout",$layout);
 $SMARTY->assign("network",$network);
@@ -162,6 +171,18 @@ $SMARTY->assign("error",$error);
 $SMARTY->display("netinfo.html");
 /*
  * $Log: netedit.php,v $
+ * Revision 1.25  2003/10/03 15:59:46  alec
+ * ujednolicenie interfejsu
+ *
+ * Revision 1.24  2003/09/05 13:11:24  lukasz
+ * - nowy sposb wywietlania informacji o bdach
+ *
+ * Revision 1.23  2003/08/30 01:11:21  lukasz
+ * - nowe pole w licie sieci: interfejs
+ *
+ * Revision 1.22  2003/08/27 19:25:42  lukasz
+ * - changed format of ipaddr storage in database
+ *
  * Revision 1.21  2003/08/24 13:12:54  lukasz
  * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
  *   redhat's :>
@@ -170,4 +191,4 @@ $SMARTY->display("netinfo.html");
  * - added CVS Log tags
  *
  */
-?>
\ No newline at end of file
+?>
