@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netinfo.php,v 1.19 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: netinfo.php,v 1.22 2003/10/03 15:59:46 alec Exp $
  */
 
 if(!$LMS->NetworkExists($_GET[id]))
@@ -30,15 +30,32 @@ if(!$LMS->NetworkExists($_GET[id]))
 	die;
 }
 
-$network = $LMS->GetNetworkRecord($_GET[id]);
-$networks = $LMS->GetNetworks();
-$layout[pagetitle]="Informacja o sieci";
+if (isset($_SESSION[ntlp][$_GET[id]]) && !isset($_GET[page]))
+	$_GET[page] = $_SESSION[ntlp][$_GET[id]];
+
+$_SESSION[ntlp][$_GET[id]] = $_GET[page];
+
+$network = $LMS->GetNetworkRecord($_GET[id],$_GET[page],1024);
+
+$layout[pagetitle]="Informacja o sieci: ".$network[name];
+
 $SMARTY->assign("layout",$layout);
 $SMARTY->assign("network",$network);
-$SMARTY->assign("networks",$networks);
 $SMARTY->display("netinfo.html");
 /*
  * $Log: netinfo.php,v $
+ * Revision 1.22  2003/10/03 15:59:46  alec
+ * ujednolicenie interfejsu
+ *
+ * Revision 1.21  2003/09/09 01:22:28  lukasz
+ * - nowe finanse
+ * - kosmetyka
+ * - bugfixy
+ * - i inne rzeczy o ktrych aktualnie nie pamitam
+ *
+ * Revision 1.20  2003/08/27 19:25:47  lukasz
+ * - changed format of ipaddr storage in database
+ *
  * Revision 1.19  2003/08/24 13:12:54  lukasz
  * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
  *   redhat's :>
@@ -47,4 +64,4 @@ $SMARTY->display("netinfo.html");
  * - added CVS Log tags
  *
  */
-?>
\ No newline at end of file
+?>
