@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,20 +21,33 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netlist.php,v 1.18 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: netlist.php,v 1.20 2003/09/01 12:37:02 lukasz Exp $
  */
 
 $layout[pagetitle]="Sieci IP";
+
 $netlist = $LMS->GetNetworkList();
-$prefixlist = $LMS->GetPrefixList();
-$netadd[prefix] = 32;
+
+$listdata[size] = $netlist[size];
+$listdata[assigned] = $netlist[assigned];
+
+unset($netlist[assigned], $netlist[size], $netlist[total]);
+
+$listdata[total] = sizeof($netlist);
+
+$SMARTY->assign("listdata",$listdata);
 $SMARTY->assign("netadd",$netadd);
 $SMARTY->assign("layout",$layout);
 $SMARTY->assign("netlist",$netlist);
-$SMARTY->assign("prefixlist",$prefixlist);
 $SMARTY->display("netlist.html");
 /*
  * $Log: netlist.php,v $
+ * Revision 1.20  2003/09/01 12:37:02  lukasz
+ * - BTS #0000067
+ *
+ * Revision 1.19  2003/08/27 19:25:56  lukasz
+ * - changed format of ipaddr storage in database
+ *
  * Revision 1.18  2003/08/24 13:12:54  lukasz
  * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
  *   redhat's :>
@@ -43,4 +56,4 @@ $SMARTY->display("netlist.html");
  * - added CVS Log tags
  *
  */
-?>
\ No newline at end of file
+?>
