@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeadd.php,v 1.32 2003/08/25 02:12:13 lukasz Exp $
+ *  $Id: nodeadd.php,v 1.38 2003/12/04 04:39:14 lukasz Exp $
  */
 
 if($LMS->UserExists($_GET[ownerid]) < 0)
@@ -71,7 +71,7 @@ if(isset($nodedata))
 	elseif(!$LMS->IsIPFree($nodedata[ipaddr]))
 		$error[ipaddr] = "Podany adres IP jest zajty!";
 
-	if($LMS->GetNodeIDByMAC($nodedata[mac]) && $_CONFIG[phpui][allow_mac_sharing] == FALSE)
+	if($LMS->GetNodeIDByMAC($nodedata[mac]) && $LMS->CONFIG[phpui][allow_mac_sharing] == FALSE)
 		$error[mac] = "Podany MAC jest ju w bazie!";
 	elseif(!check_mac($nodedata[mac]))
 		$error[mac] = "Podany adres MAC jest nieprawidowy!";
@@ -79,8 +79,8 @@ if(isset($nodedata))
 	if(! $LMS->UserExists($nodedata[ownerid]))
 		$error[user] = "Prosz wybra uytkownika!";
 
-	if($LMS->GetUserStatus($nodedata[ownerid]) != 3 || $LMS->UserExists($nodedata[ownerid]) == -1)
-		$error[user] = "Wybrany uytkownik jest bdny!";
+	if($LMS->GetUserStatus($nodedata[ownerid]) != 3 || $LMS->UserExists($nodedata[ownerid]) != TRUE)
+		$error[user] = "Wybrany uytkownik $nodedata[ownerid] jest bdny!";
 
 	if(!$error)
 	{
@@ -91,6 +91,8 @@ if(isset($nodedata))
 		
 }
 
+$nodedata[access] = 1;
+
 if($_GET[ownerid] && $LMS->UserExists($_GET[ownerid]) > 0)
 {
 	$nodedata[ownerid] = $_GET[ownerid];
@@ -107,9 +109,15 @@ if(isset($_GET[prename])&&$nodedata[name]=="")
 	$nodedata[name] = $_GET[prename];
 		
 
-$layout[pagetitle]="Dodanie nowego komputera";
+$layout[pagetitle]="Nowy komputer";
 
-$SMARTY->assign("balancelist",$LMS->GetUserBalanceList($nodedata[ownerid]));
+$tariffs = $LMS->GetTariffs();
+$balancelist = $LMS->GetUserBalanceList($nodedata[ownerid]);
+$assignments = $LMS->GetUserAssignments($nodedata[ownerid]);
+
+$SMARTY->assign("balancelist",$balancelist);
+$SMARTY->assign("assignments",$assignments);
+$SMARTY->assign("tariffs",$tariffs);
 $SMARTY->assign("users",$users);
 $SMARTY->assign("error",$error);
 $SMARTY->assign("userinfo",$userinfo);
@@ -120,6 +128,25 @@ $SMARTY->display("nodeadd.html");
 
 /*
  * $Log: nodeadd.php,v $
+ * Revision 1.38  2003/12/04 04:39:14  lukasz
+ * - porzdki
+ * - troch podubane przy parsowaniu pliku konfiguracyjnego
+ *
+ * Revision 1.37  2003/10/07 19:15:05  alec
+ * ujednolicenie naglowka
+ *
+ * Revision 1.36  2003/09/12 02:52:57  lukasz
+ * - cosmetics
+ *
+ * Revision 1.35  2003/09/09 01:44:07  lukasz
+ * - poprawki node{edit,info,add}
+ *
+ * Revision 1.34  2003/09/01 12:34:05  lukasz
+ * - BTS #0000066
+ *
+ * Revision 1.33  2003/08/27 19:26:15  lukasz
+ * - changed format of ipaddr storage in database
+ *
  * Revision 1.32  2003/08/25 02:12:13  lukasz
  * - zmieniona obsuga usuwania userw
  *
