@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeedit.php,v 1.24 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: nodeedit.php,v 1.41 2003/12/04 04:39:14 lukasz Exp $
  */
 
 if(!$LMS->NodeExists($_GET[id]))
@@ -30,6 +30,13 @@ if(!$LMS->NodeExists($_GET[id]))
 	else
 		header("Location: ?m=nodelist");
 
+if($_GET[action]=="link")
+{
+	$LMS->NetDevLinkNode($_GET[id],$_GET[devid]);
+	header("Location: ?m=nodeinfo&id=".$_GET[id]);
+	die;
+}
+
 $nodeid = $_GET[id];
 $ownerid = $LMS->GetNodeOwner($nodeid);
 $_SESSION[backto] = $_SERVER[QUERY_STRING];
@@ -39,16 +46,17 @@ if(!isset($_GET[ownerid]))
 							
 $owner = $ownerid;
 $userinfo=$LMS->GetUser($owner);
-$layout[pagetitle]="Informacje o uytkowniku ".$userinfo[username]." - edycja komputera ".$LMS->GetNodeName($_GET[id]);
+$layout[pagetitle]="Informacje o uytkowniku: ".$userinfo[username]." - edycja komputera: ".$LMS->GetNodeName($_GET[id]);
 
 $nodeedit = $_POST[nodeedit];
 $usernodes = $LMS->GetUserNodes($owner);
 $nodeinfo = $LMS->GetNode($_GET[id]);
+
 if(isset($nodeedit))
 {
 	$nodeedit[ipaddr] = $_POST[nodeeditipaddr];
 	$nodeedit[mac] = $_POST[nodeeditmac];
-
+	$nodeedit[mac] = str_replace("-",":",$nodeedit[mac]);
 	foreach($nodeedit as $key => $value)
 		$nodeedit[$key] = trim($value);
 	
@@ -82,7 +90,7 @@ if(isset($nodeedit))
 		if(
 				$LMS->GetNodeIDByMAC($nodeedit[mac]) &&
 				$LMS->GetNodeMACByID($nodeedit[id])!=$nodeedit[mac] &&
-				$_CONFIG[phpui][allow_mac_sharing] == FALSE
+				$LMS->CONFIG[phpui][allow_mac_sharing] == FALSE
 		)
 		{
 			$error[mac] = "Podany adres MAC jest ju przypisany do innego komputera!";
@@ -100,8 +108,16 @@ if(isset($nodeedit))
 	elseif(!eregi("^[_a-z0-9-]+$",$nodeedit[name]))
 		$error[name] = "Podana nazwa zawiera niepoprawne znaki!";
 
-	if($nodeedit[access]!="Y")
-		$nodeedit[access] = "N";
+	if($nodeedit[access]!=1)
+		$nodeedit[access] = 0;
+	
+	if($nodeinfo[netdev] != $nodeedit[netdev] && $nodeedit[netdev] != 0)
+	{
+		$netdev = $LMS->GetNetDev($nodeedit[netdev]); 
+		if($netdev[ports] <= $netdev[takenports])
+		    $error[netdev] = "Brak wolnych portw w wybranym urzdzeniu!";
+		$nodeinfo[netdev] = $nodeedit[netdev];
+	}
 	
 	$nodeinfo[name] = $nodeedit[name];
 	$nodeinfo[mac] = $nodeedit[mac];
@@ -109,6 +125,7 @@ if(isset($nodeedit))
 	$nodeinfo[access] = $nodeedit[access];
 	$nodeinfo[ownerid] = $nodeedit[ownerid];
 
+
 	if(!$error)
 	{
 		$LMS->NodeUpdate($nodeedit);
@@ -118,9 +135,20 @@ if(isset($nodeedit))
 
 if($userinfo[status]==3) $userinfo[shownodes] = TRUE;
 $users = $LMS->GetUserNames();
+$tariffs = $LMS->GetTariffs();
+$assignments = $LMS->GetUserAssignments($ownerid);
+$balancelist = $LMS->GetUserBalanceList($owner);
 
+$nodeinfo[netdev] = $LMS->GetNetDev($nodeinfo[netdev]);
+$netdevices = $LMS->GetNetDevList();
+unset($netdevices[total]);
+unset($netdevices[direction]);
+unset($netdevices[order]);
 
-$SMARTY->assign("balancelist",$LMS->GetUserBalanceList($owner));
+$SMARTY->assign("netdevices",$netdevices);
+$SMARTY->assign("balancelist",$balancelist);
+$SMARTY->assign("assignments",$assignments);
+$SMARTY->assign("tariffs",$tariffs);
 $SMARTY->assign("error",$error);
 $SMARTY->assign("userinfo",$userinfo);
 $SMARTY->assign("layout",$layout);
@@ -129,6 +157,49 @@ $SMARTY->assign("users",$users);
 $SMARTY->display("nodeedit.html");
 /*
  * $Log: nodeedit.php,v $
+ * Revision 1.41  2003/12/04 04:39:14  lukasz
+ * - porzdki
+ * - troch podubane przy parsowaniu pliku konfiguracyjnego
+ *
+ * Revision 1.40  2003/10/11 10:17:03  lexx
+ * - computer -> node i inne drobne poprawki
+ *
+ * Revision 1.39  2003/10/06 04:46:49  lukasz
+ * - temp save
+ *
+ * Revision 1.38  2003/10/04 12:41:28  lexx
+ * - co za duzo to nie zdrowo
+ *
+ * Revision 1.36  2003/10/02 20:14:13  alec
+ * dodana mozliwosc odlaczenia kompa od urzadzenia
+ *
+ * Revision 1.35  2003/10/02 19:40:22  alec
+ * dodane sprawdzanie ilosci portow w netdev
+ *
+ * Revision 1.32  2003/09/23 19:11:46  alec
+ * kosmetyka - dodany dwukropek
+ *
+ * Revision 1.31  2003/09/22 18:12:33  lexx
+ * - komputery moga sie linkowac
+ *
+ * Revision 1.30  2003/09/19 11:00:03  lukasz
+ * - temporary save
+ *
+ * Revision 1.29  2003/09/12 02:52:57  lukasz
+ * - cosmetics
+ *
+ * Revision 1.28  2003/09/09 01:44:07  lukasz
+ * - poprawki node{edit,info,add}
+ *
+ * Revision 1.27  2003/09/07 18:53:53  lukasz
+ * *** empty log message ***
+ *
+ * Revision 1.26  2003/09/07 18:52:39  lukasz
+ * - add $nodedata[mac] = str_replace("-",":",$nodedata[mac]);
+ *
+ * Revision 1.25  2003/08/27 20:18:42  lukasz
+ * - changed nodes.access from ENUM to BOOL;
+ *
  * Revision 1.24  2003/08/24 13:12:54  lukasz
  * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
  *   redhat's :>
@@ -137,4 +208,6 @@ $SMARTY->display("nodeedit.html");
  * - added CVS Log tags
  *
  */
-?>
\ No newline at end of file
+?>
+
+
