@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodelist.php,v 1.25 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: nodelist.php,v 1.26 2003/12/04 04:39:14 lukasz Exp $
  */
 
 $layout[pagetitle]="Lista komputerw";
@@ -52,7 +52,7 @@ if (isset($_SESSION[nlp]) && !isset($_GET[page]))
         $_GET[page] = $_SESSION[nlp];
 	
 $page = (! $_GET[page] ? 1 : $_GET[page]);
-$pagelimit = (! $_CONFIG[phpui][nodelist_pagelimit] ? $listdata[total] : $_CONFIG[phpui][nodelist_pagelimit]);
+$pagelimit = (! $LMS->CONFIG[phpui][nodelist_pagelimit] ? $listdata[total] : $LMS->CONFIG[phpui][nodelist_pagelimit]);
 $start = ($page - 1) * $pagelimit;
 
 $_SESSION[nlp] = $page;
@@ -66,6 +66,10 @@ $SMARTY->display("nodelist.html");
 
 /*
  * $Log: nodelist.php,v $
+ * Revision 1.26  2003/12/04 04:39:14  lukasz
+ * - porzdki
+ * - troch podubane przy parsowaniu pliku konfiguracyjnego
+ *
  * Revision 1.25  2003/08/24 13:12:54  lukasz
  * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
  *   redhat's :>
