@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,12 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodesearch.php,v 1.15 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: nodesearch.php,v 1.17 2003/12/04 04:39:14 lukasz Exp $
  */
 
 $layout[pagetitle]="Wyszukiwanie komputerw";
 $SMARTY->assign("layout",$layout);
 
+$_SESSION[backto] = $_SERVER[QUERY_STRING];
+
 $search = $_POST[search];
 
 if(!isset($search))
@@ -62,7 +64,7 @@ if($_GET[search]==1 || isset($_GET[search]))
 		
 	$page = (! $_GET[page] ? 1 : $_GET[page]);
 	
-	$pagelimit = (! $_CONFIG[phpui][nodelist_pagelimit] ? $listdata[total] : $_CONFIG[phpui][nodelist_pagelimit]);
+	$pagelimit = (! $LMS->CONFIG[phpui][nodelist_pagelimit] ? $listdata[total] : $LMS->CONFIG[phpui][nodelist_pagelimit]);
 	$start = ($page - 1) * $pagelimit;
 	$_SESSION[nslp] = $page;
 	
@@ -80,6 +82,13 @@ else
 }
 /*
  * $Log: nodesearch.php,v $
+ * Revision 1.17  2003/12/04 04:39:14  lukasz
+ * - porzdki
+ * - troch podubane przy parsowaniu pliku konfiguracyjnego
+ *
+ * Revision 1.16  2003/09/22 21:21:44  alec
+ * many updates
+ *
  * Revision 1.15  2003/08/24 13:12:54  lukasz
  * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
  *   redhat's :>
