@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: reload.php,v 1.17 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: reload.php,v 1.20 2003/12/04 04:39:14 lukasz Exp $
  */
 
 // Agggrrr. Nie zwracajcie uwagi na styl pisania *TEGO* kawaka kodu :)
@@ -33,8 +33,8 @@ $SMARTY->display("header.html");
 
 ?><H1>Przeadowanie ustawie</H1><?php
 
-$_RELOAD_TYPE = (! $_CONFIG[phpui]['reload_type'] ? "sql" : $_CONFIG[phpui]['reload_type']);
-$_EXECCMD = (! $_CONFIG[phpui]['reload_execcmd'] ? "/bin/true" : $_CONFIG[phpui]['reload_execcmd']);
+$_RELOAD_TYPE = $LMS->CONFIG['phpui']['reload_type'];
+$_EXECCMD = $LMS->CONFIG['phpui']['reload_execcmd'];
 
 switch($_RELOAD_TYPE)
 {
@@ -52,20 +52,20 @@ switch($_RELOAD_TYPE)
 	break;
 
 	case "sql":
-		if(isset($_CONFIG[phpui]['reload_sqlquery']))
+		if(isset($LMS->CONFIG['phpui']['reload_sqlquery']))
 		{
-			$sqlqueries = explode(";",($_CONFIG[phpui]['reload_sqlquery']));
+			$sqlqueries = explode(";",($LMS->CONFIG['phpui']['reload_sqlquery']));
 			echo '<TABLE WIDTH="100%" BGCOLOR="#F4F0EC" CELLPADDING="5"><TR><TD CLASS="FALL">';
 			foreach($sqlqueries as $query)
 			{
-				$query = str_replace("%TIME%",$LMS->sqlTSfmt(),$query);
+				$query = str_replace("%TIME%","?NOW?",$query);
 				echo "<P><B>Wykonuje:</B></P>";
 				echo "<PRE>".$query."</PRE>";
-				$ADB->Execute($query);
+				$LMS->DB->Execute($query);
 			}
 			echo '</TD></TR></TABLE>';
 		}else{
-			if(isset($_GET[cancel]))
+			if(isset($_GET['cancel']))
 			{
 				echo 'Usunito zlecenie przeadowania konfiguracji.';
 				$LMS->DeleteTS("_force");
@@ -92,6 +92,16 @@ $SMARTY->display("footer.html");
 
 /*
  * $Log: reload.php,v $
+ * Revision 1.20  2003/12/04 04:39:14  lukasz
+ * - porzdki
+ * - troch podubane przy parsowaniu pliku konfiguracyjnego
+ *
+ * Revision 1.19  2003/09/07 18:46:57  lexx
+ * - die ADOB, die!
+ *
+ * Revision 1.18  2003/08/31 19:05:14  lukasz
+ * - 19:48.32| < Lexx__> Baseciq, ten tego w reload.php uzywasz sqlTSfmt() ktore jest zdaje sie obsolete
+ *
  * Revision 1.17  2003/08/24 13:12:54  lukasz
  * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
  *   redhat's :>
