@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,21 +21,37 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffinfo.php,v 1.13 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: tariffinfo.php,v 1.16 2003/10/02 21:18:18 alec Exp $
  */
 if(!$LMS->TariffExists($_GET[id]))
 {
 	header("Location: ?m=tarifflist");
 	die;
 }
-$layout[pagetitle]="Informacja o taryfie";
+$tariff = $LMS->GetTariff($_GET[id]);
+$layout[pagetitle] = "Informacja o taryfie: ".$tariff[name];
+
 $_SESSION[backto] = $_SERVER[QUERY_STRING];
+
 $SMARTY->assign("layout",$layout);
-$SMARTY->assign("tariff",$LMS->GetTariff($_GET[id]));
+$SMARTY->assign("tariff",$tariff);
 $SMARTY->assign("tariffs",$LMS->GetTariffs());
 $SMARTY->display("tariffinfo.html");
+
 /*
  * $Log: tariffinfo.php,v $
+ * Revision 1.16  2003/10/02 21:18:18  alec
+ * standardization with rest of UI
+ *
+ * Revision 1.15  2003/09/26 17:44:10  alec
+ * ujednolicone nagwki (dodany ':')
+ *
+ * Revision 1.14  2003/09/09 01:22:28  lukasz
+ * - nowe finanse
+ * - kosmetyka
+ * - bugfixy
+ * - i inne rzeczy o ktrych aktualnie nie pamitam
+ *
  * Revision 1.13  2003/08/24 13:12:54  lukasz
  * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
  *   redhat's :>
@@ -44,4 +60,4 @@ $SMARTY->display("tariffinfo.html");
  * - added CVS Log tags
  *
  */
-?>
\ No newline at end of file
+?>
