@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,12 +21,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffmove.php,v 1.11 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: tariffmove.php,v 1.12 2003/09/09 01:22:28 lukasz Exp $
  */
 
-if($LMS->TariffExists($_GET[from])&&$LMS->TariffExists($_GET[to])&&$_GET[is_sure] = 1)
+if($LMS->TariffExists($_GET[from]) && $LMS->TariffExists($_GET[to]) && $_GET[is_sure] = 1)
 {
-	$ADB->Execute("UPDATE users SET tariff=? WHERE tariff=? AND status=3",array($_GET[to],$_GET[from]));
+	$LMS->TariffMove($_GET[from],$_GET[to]);
 	header("Location: ?m=tariffinfo&id=".$_GET[to]);
 	die;
 }
@@ -34,6 +34,12 @@ else
 	header("Location: ?".$_SESSION[backto]);
 /*
  * $Log: tariffmove.php,v $
+ * Revision 1.12  2003/09/09 01:22:28  lukasz
+ * - nowe finanse
+ * - kosmetyka
+ * - bugfixy
+ * - i inne rzeczy o ktrych aktualnie nie pamitam
+ *
  * Revision 1.11  2003/08/24 13:12:54  lukasz
  * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
  *   redhat's :>
@@ -42,4 +48,4 @@ else
  * - added CVS Log tags
  *
  */
-?>
\ No newline at end of file
+?>
