@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: userdel.php,v 1.19 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: userdel.php,v 1.21 2003/11/22 17:44:48 alec Exp $
  */
 
 $layout[pagetitle]="Usunicie uytkownika ID: ".sprintf("%04d",$_GET[id]);
@@ -40,7 +40,7 @@ if (!$LMS->UserExists($_GET[id]))
 		$body .= "<P>Wszystkie dane uytkownika zostan utracone, a take wszystkie przypisane temu uytkownikowi komputery zostan usunite.</P>";
 		$body .= "<P><A HREF=\"?m=userdel&id=".$_GET[id]."&is_sure=1\">Tak, jestem pewien.</A></P>";
 	}else{
-		header("Location: ?m=".$_SESSION[lastmodule]);
+		header("Location: ?".$_SESSION[backto]);
 		$body = "<H1>".$layout[pagetitle]."</H1>";
 		$body .= "<P>Uytkownik ".$LMS->GetUserName($_GET[id])." zosta usunity.</P>";
 		$LMS->DeleteUser($_GET[id]);
@@ -54,6 +54,12 @@ $SMARTY->display("footer.html");
 
 /*
  * $Log: userdel.php,v $
+ * Revision 1.21  2003/11/22 17:44:48  alec
+ * jeli usuwamy usera z listy to wracamy do listy, a nie do userinfo
+ *
+ * Revision 1.20  2003/08/27 20:32:54  lukasz
+ * - changed another ENUM (users.deleted) to BOOL
+ *
  * Revision 1.19  2003/08/24 13:12:54  lukasz
  * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
  *   redhat's :>
@@ -62,4 +68,4 @@ $SMARTY->display("footer.html");
  * - added CVS Log tags
  *
  */
-?>
\ No newline at end of file
+?>
