@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.1.2b
+ * LMS version 1.1.5 Amaonet
  *
  *  (C) Copyright 2001-2003 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: userlist.php,v 1.31 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: userlist.php,v 1.33 2003/12/04 04:39:14 lukasz Exp $
  */
 
 $_SESSION[backto] = $_SERVER[QUERY_STRING];
@@ -53,7 +53,7 @@ $listdata[over] = $userlist[over];
 $listdata[direction] = $userlist[direction];
 
 $page = (! $_GET[page] ? 1 : $_GET[page]); 
-$pagelimit = (! $_CONFIG[phpui][userlist_pagelimit] ? $listdata[total] : $_CONFIG[phpui][userlist_pagelimit]);
+$pagelimit = (! $LMS->CONFIG[phpui][userlist_pagelimit] ? $listdata[total] : $LMS->CONFIG[phpui][userlist_pagelimit]);
 $start = ($page - 1) * $pagelimit;
 
 $_SESSION[ulp] = $page;
@@ -67,7 +67,6 @@ unset($userlist[direction]);
 $SMARTY->assign("layout",$layout);
 $SMARTY->assign("userlist",$userlist);
 $SMARTY->assign("listdata",$listdata);
-$SMARTY->assign("tariffs",$LMS->GetTariffs());
 $SMARTY->assign("pagelimit",$pagelimit);
 $SMARTY->assign("page",$page);
 $SMARTY->assign("start",$start);
@@ -76,6 +75,13 @@ $SMARTY->display("userlist.html");
 
 /*
  * $Log: userlist.php,v $
+ * Revision 1.33  2003/12/04 04:39:14  lukasz
+ * - porzdki
+ * - troch podubane przy parsowaniu pliku konfiguracyjnego
+ *
+ * Revision 1.32  2003/09/08 09:10:59  lukasz
+ * - removed unused assign with GetTariffs()
+ *
  * Revision 1.31  2003/08/24 13:12:54  lukasz
  * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
  *   redhat's :>
@@ -84,4 +90,4 @@ $SMARTY->display("userlist.html");
  * - added CVS Log tags
  *
  */
-?>
\ No newline at end of file
+?>
